@@ -6,7 +6,7 @@ Params::Classify - argument type classification
 
 	use Params::Classify qw(scalar_class
 		is_undef
-		is_string is_number is_pure_string is_pure_number
+		is_string is_number
 		is_glob
 		is_ref ref_type
 		is_blessed blessed_class
@@ -18,8 +18,6 @@ Params::Classify - argument type classification
 
 	$ok = is_string($foo);
 	$ok = is_number($foo);
-	$ok = is_pure_string($foo);
-	$ok = is_pure_number($foo);
 
 	$ok = is_glob($foo);
 
@@ -46,6 +44,9 @@ type restrictions.  Type enforcement may, of course, be built using
 these classification functions, but the reader's attention is drawn
 to L<Params::Validate>.
 
+This module is implemented in XS, with a pure Perl backup version for
+systems that can't handle XS.
+
 =cut
 
 package Params::Classify;
@@ -53,22 +54,51 @@ package Params::Classify;
 use warnings;
 use strict;
 
-use Exporter;
-use Scalar::Util 1.01 qw(blessed reftype);
-
-our $VERSION = "0.005";
-
-our @ISA = qw(Exporter);
+our $VERSION = "0.007";
 
+use parent "Exporter";
 our @EXPORT_OK = qw(
 	scalar_class
 	is_undef
-	is_string is_number is_pure_string is_pure_number
+	is_string is_number
 	is_glob
 	is_ref ref_type
 	is_blessed blessed_class is_strictly_blessed is_able
 );
 
+eval { local $SIG{__DIE__};
+	require XSLoader;
+	XSLoader::load(__PACKAGE__, $VERSION);
+};
+
+if($@ eq "") {
+	close(DATA);
+	*is_number = sub($) {
+		return 0 unless &is_string;
+		my($arg) = @_;
+		my $warned;
+		local $SIG{__WARN__} = sub { $warned = 1; };
+		{ no warnings "void"; 0 + $arg; }
+		return !$warned;
+	};
+} else {
+	(my $filename = __FILE__) =~ tr# -~##cd;
+	local $/ = undef;
+	my $pp_code = "#line 99 \"$filename\"\n".<DATA>;
+	close(DATA);
+	{
+		local $SIG{__DIE__};
+		eval $pp_code;
+	}
+	die $@ if $@ ne "";
+}
+
+1;
+
+__DATA__
+
+use Scalar::Util 1.01 qw(blessed reftype);
+
 =head1 TYPE CLASSIFICATION
 
 This module divides up scalar values into the following classes:
@@ -110,7 +140,7 @@ of the reference.)
 Each of these functions takes one scalar argument to be tested, possibly
 with other arguments specifying details of the test.  Any scalar value is
 acceptable for the argument to be tested (called ARG below).  Each "is_"
-function returns a simple boolean result.
+function returns a simple truth value result.
 
 =head2 Classification
 
@@ -222,42 +252,6 @@ sub is_number($) {
 	return !$warned;
 }
 
-=item is_pure_string(ARG)
-
-This returns true iff ARG is defined and an ordinary scalar (i.e.,
-satisfies C<is_string> above) and is fully described by its string value.
-That is, its numeric value is that which would be obtained by automatic
-conversion from the string value.  Such a scalar could have originated
-as a string literal or constructed string.  This excludes many floating
-point number values which stringify lossily.
-
-=cut
-
-sub is_pure_string($) {
-	my($val) = @_;
-	return 0 unless is_string($val);
-	require Scalar::Number;
-	local $SIG{__WARN__} = sub { };
-	return Scalar::Number::sclnum_id_cmp("$val", $val) == 0;
-}
-
-=item is_pure_number(ARG)
-
-This returns true iff ARG is defined and an ordinary scalar (i.e.,
-satisfies C<is_string> above) and is fully described by its numeric value.
-That is, its string value is that which would be obtained by automatic
-conversion from the numeric value.  Such a scalar could have originated
-as a numeric literal or calculated number.  This excludes most strings.
-
-=cut
-
-sub is_pure_number($) {
-	my($val) = @_;
-	return 0 unless is_string($val);
-	require Scalar::Number;
-	return Scalar::Number::scalar_num_part($val) eq $val;
-}
-
 =back
 
 =head2 Typeglobs
@@ -446,7 +440,12 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2004, 2006, 2007 Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2004, 2006, 2007, 2009
+Andrew Main (Zefram) <zefram@fysh.org>
+
+Copyright (C) 2009 PhotoBox Ltd
+
+=head1 LICENSE
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
